.. Copyright 2020-2022 Robert Bosch Car Multimedia GmbH

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

Json Preprocessor's Package Description
=======================================

Getting Started
---------------

The JsonPreprocessor is a Python3 package which allows programmers to handle  
additional features in json files such as

* add comments
* import other json files
* overwrite already existing parameters with new values

These json files will be handled by the JsonPreprocessor which returns as result
a dictionary object of the deserialized data.

How to install
--------------

Firstly, clone **python-jsonpreprocessor** repository to your machine.

Then go to python-jsonpreprocessor, using the 2 common commands below to build or install this package:

.. code-block::

    setup.py build      will build the package underneath 'build/'
    setup.py install    will install the package

After the build processes is completed, the package is located in 'build/', and the generated 
package documentation is located in 'doc/_build/'.


Package Documentation
---------------------

A detailed documentation of the Json Preprocessor's package can be found here: `Json-Preprocessor.pdf <https://github.com/test-fullautomation/python-jsonpreprocessor/blob/develop/doc/_build/latex/Json-Preprocessor.pdf>`_

Feedback
--------

To give us a feedback, you can send an email to `Thomas Pollerspöck <mailto:Thomas.Pollerspoeck@de.bosch.com>`_ 

In case you want to report a bug or request any interesting feature, please don't 
hesitate to raise a ticket.

Maintainers
-----------

`Thomas Pollerspöck <mailto:Thomas.Pollerspoeck@de.bosch.com>`_

Contributors
------------

`Mai Dinh Nam Son <mailto:son.maidinhnam@vn.bosch.com>`_

`Tran Duy Ngoan <mailto:Ngoan.TranDuy@vn.bosch.com>`_

License
-------

json-preprocessor is open source software provided under the `Apache License
2.0`__. 

__ http://apache.org/licenses/LICENSE-2.0
